" Name:         torte
" Description:  Remake of torte (grey on black)
" Author:       Original maintainer Thorsten Maerz <info@netztorte.de>
" Maintainer:   Original maintainer Thorsten Maerz <info@netztorte.de>
" URL:          https://github.com/vim/colorschemes
" License:      Same as Vim
" Last Change:  2026 Apr 24

" Generated by Colortemplate v3.0.0-rc1

set background=dark

hi clear
let g:colors_name = 'torte'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

let g:terminal_ansi_colors = ['#000000', '#cd0000', '#00cd00', '#cdcd00', '#0000ee', '#cd00cd', '#00cdcd', '#e5e5e5', '#7f7f7f', '#ff0000', '#00ff00', '#ffff00', '#5c5cff', '#ff00ff', '#00ffff', '#ffffff']

hi! link CurSearch Search
hi! link CursorLineFold CursorLine
hi! link CursorLineSign CursorLine
hi! link Float Number
hi! link Function Identifier
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link MessageWindow Pmenu
hi! link Number Constant
hi! link PopupNotification Todo
hi! link StatusLineTerm StatusLine
hi! link StatusLineTermNC StatusLineNC
hi! link TabPanel Normal
hi! link TabPanelFill EndOfBuffer
hi! link Terminal Normal

hi Normal guifg=#cccccc guibg=#000000 guisp=NONE gui=NONE ctermfg=251 ctermbg=16 cterm=NONE term=NONE
hi ColorColumn guifg=#cccccc guibg=#8b0000 guisp=NONE gui=NONE ctermfg=251 ctermbg=88 cterm=NONE term=reverse
hi Comment guifg=#80a0ff guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=bold
hi Conceal guifg=#666666 guibg=NONE guisp=NONE gui=NONE ctermfg=242 ctermbg=NONE cterm=NONE term=NONE
hi Constant guifg=#ffa0a0 guibg=NONE guisp=NONE gui=NONE ctermfg=217 ctermbg=NONE cterm=NONE term=NONE
hi Cursor guifg=#000000 guibg=#00ff00 guisp=NONE gui=bold ctermfg=16 ctermbg=46 cterm=NONE term=reverse
hi CursorColumn guifg=NONE guibg=#666666 guisp=NONE gui=NONE ctermfg=NONE ctermbg=242 cterm=NONE term=NONE
hi CursorIM guifg=NONE guibg=fg guisp=NONE gui=NONE ctermfg=NONE ctermbg=fg cterm=NONE term=NONE
hi CursorLine guifg=NONE guibg=#666666 guisp=NONE gui=NONE ctermfg=NONE ctermbg=242 cterm=NONE term=underline
hi CursorLineNr guifg=#ffff00 guibg=#666666 guisp=NONE gui=NONE ctermfg=226 ctermbg=242 cterm=NONE term=bold
hi DiffAdd guifg=#ffffff guibg=#5f875f guisp=NONE gui=NONE ctermfg=231 ctermbg=65 cterm=NONE term=reverse
hi DiffChange guifg=#ffffff guibg=#5f87af guisp=NONE gui=NONE ctermfg=231 ctermbg=67 cterm=NONE term=NONE
hi DiffDelete guifg=#ffffff guibg=#af5faf guisp=NONE gui=NONE ctermfg=231 ctermbg=133 cterm=NONE term=reverse
hi DiffText guifg=#000000 guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=16 ctermbg=251 cterm=NONE term=reverse
hi Directory guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=NONE
hi EndOfBuffer guifg=#0000ff guibg=NONE guisp=NONE gui=bold ctermfg=21 ctermbg=NONE cterm=NONE term=NONE
hi Error guifg=#ffffff guibg=#ff0000 guisp=NONE gui=NONE ctermfg=231 ctermbg=196 cterm=NONE term=bold,reverse
hi ErrorMsg guifg=#ffffff guibg=#cd0000 guisp=NONE gui=NONE ctermfg=231 ctermbg=160 cterm=NONE term=bold,reverse
hi FoldColumn guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=NONE
hi Folded guifg=#00cdcd guibg=#3a3a3a guisp=NONE gui=NONE ctermfg=44 ctermbg=237 cterm=NONE term=NONE
hi Identifier guifg=#40ffff guibg=NONE guisp=NONE gui=NONE ctermfg=87 ctermbg=NONE cterm=NONE term=NONE
hi Ignore guifg=#000000 guibg=#000000 guisp=NONE gui=NONE ctermfg=16 ctermbg=16 cterm=NONE term=NONE
hi IncSearch guifg=#00cd00 guibg=#000000 guisp=NONE gui=reverse ctermfg=40 ctermbg=16 cterm=reverse term=bold,reverse,underline
hi LineNr guifg=#7f7f7f guibg=NONE guisp=NONE gui=NONE ctermfg=102 ctermbg=NONE cterm=NONE term=NONE
hi MatchParen guifg=NONE guibg=#008b8b guisp=NONE gui=NONE ctermfg=NONE ctermbg=30 cterm=NONE term=bold,underline
hi ModeMsg guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
hi MoreMsg guifg=#2e8b57 guibg=NONE guisp=NONE gui=bold ctermfg=29 ctermbg=NONE cterm=bold term=NONE
hi NonText guifg=#0000ff guibg=NONE guisp=NONE gui=bold ctermfg=21 ctermbg=NONE cterm=NONE term=NONE
hi Pmenu guifg=fg guibg=#303030 guisp=NONE gui=NONE ctermfg=fg ctermbg=236 cterm=NONE term=reverse
hi PmenuMatch guifg=#ff00ff guibg=#303030 guisp=NONE gui=NONE ctermfg=201 ctermbg=236 cterm=NONE term=NONE
hi PmenuMatchSel guifg=#ff00ff guibg=#ffff00 guisp=NONE gui=NONE ctermfg=201 ctermbg=226 cterm=NONE term=NONE
hi PmenuSbar guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
hi PmenuSel guifg=#000000 guibg=#ffff00 guisp=NONE gui=NONE ctermfg=16 ctermbg=226 cterm=NONE term=bold
hi PmenuThumb guifg=NONE guibg=#bebebe guisp=NONE gui=NONE ctermfg=NONE ctermbg=250 cterm=NONE term=NONE
hi PreProc guifg=#ff80ff guibg=NONE guisp=NONE gui=NONE ctermfg=213 ctermbg=NONE cterm=NONE term=NONE
hi Question guifg=#00ff00 guibg=NONE guisp=NONE gui=bold ctermfg=46 ctermbg=NONE cterm=bold term=standout
hi QuickFixLine guifg=#000000 guibg=#cdcd00 guisp=NONE gui=NONE ctermfg=16 ctermbg=184 cterm=NONE term=NONE
hi Search guifg=#ff0000 guibg=#000000 guisp=NONE gui=reverse ctermfg=196 ctermbg=16 cterm=reverse term=reverse
hi SignColumn guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=reverse
hi Special guifg=#ffa500 guibg=NONE guisp=NONE gui=NONE ctermfg=214 ctermbg=NONE cterm=NONE term=NONE
hi SpecialKey guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=bold
hi SpellBad guifg=#ff0000 guibg=NONE guisp=#ff0000 gui=undercurl ctermfg=196 ctermbg=NONE cterm=underline term=underline
hi SpellCap guifg=#5c5cff guibg=NONE guisp=#5c5cff gui=undercurl ctermfg=63 ctermbg=NONE cterm=underline term=underline
hi SpellLocal guifg=#ff00ff guibg=NONE guisp=#ff00ff gui=undercurl ctermfg=201 ctermbg=NONE cterm=underline term=underline
hi SpellRare guifg=#00ffff guibg=NONE guisp=#00ffff gui=undercurl ctermfg=51 ctermbg=NONE cterm=underline term=underline
hi Statement guifg=#ffff60 guibg=NONE guisp=NONE gui=NONE ctermfg=227 ctermbg=NONE cterm=NONE term=NONE
hi StatusLine guifg=#ffffff guibg=#0000ee guisp=NONE gui=bold ctermfg=231 ctermbg=20 cterm=bold term=bold,reverse
hi StatusLineNC guifg=#000000 guibg=#e5e5e5 guisp=NONE gui=NONE ctermfg=16 ctermbg=254 cterm=NONE term=bold,underline
hi TabLine guifg=#ffffff guibg=#7f7f7f guisp=NONE gui=NONE ctermfg=231 ctermbg=102 cterm=NONE term=bold,underline
hi TabLineFill guifg=NONE guibg=#000000 guisp=NONE gui=reverse ctermfg=NONE ctermbg=16 cterm=reverse term=NONE
hi TabLineSel guifg=#cccccc guibg=#000000 guisp=NONE gui=bold ctermfg=251 ctermbg=16 cterm=bold term=bold,reverse
hi Title guifg=#ff00ff guibg=NONE guisp=NONE gui=bold ctermfg=201 ctermbg=NONE cterm=bold term=NONE
hi TitleBar guifg=#cccccc guibg=#3c3c3c guisp=NONE gui=NONE ctermfg=251 ctermbg=237 cterm=NONE term=NONE
hi TitleBarNC guifg=#7f7f7f guibg=#2c2c2c guisp=NONE gui=NONE ctermfg=102 ctermbg=236 cterm=NONE term=NONE
hi Todo guifg=#ffff00 guibg=#000000 guisp=NONE gui=reverse ctermfg=226 ctermbg=16 cterm=reverse term=bold,reverse
hi ToolbarButton guifg=#000000 guibg=#e5e5e5 guisp=NONE gui=bold ctermfg=16 ctermbg=254 cterm=bold term=bold,reverse
hi ToolbarLine guifg=NONE guibg=#000000 guisp=NONE gui=NONE ctermfg=NONE ctermbg=16 cterm=NONE term=reverse
hi Type guifg=#60ff60 guibg=NONE guisp=NONE gui=NONE ctermfg=83 ctermbg=NONE cterm=NONE term=NONE
hi Underlined guifg=#80a0ff guibg=NONE guisp=NONE gui=underline ctermfg=111 ctermbg=NONE cterm=underline term=underline
hi VertSplit guifg=#000000 guibg=#0000ee guisp=NONE gui=NONE ctermfg=16 ctermbg=20 cterm=NONE term=NONE
hi VertSplitNC guifg=#000000 guibg=#e5e5e5 guisp=NONE gui=NONE ctermfg=16 ctermbg=254 cterm=NONE term=NONE
hi Visual guifg=#000000 guibg=#a9a9a9 guisp=NONE gui=bold ctermfg=16 ctermbg=248 cterm=NONE term=reverse
hi VisualNOS guifg=NONE guibg=#000000 guisp=NONE gui=bold,underline ctermfg=NONE ctermbg=16 cterm=underline term=NONE
hi WarningMsg guifg=#ff0000 guibg=NONE guisp=NONE gui=NONE ctermfg=196 ctermbg=NONE cterm=NONE term=standout
hi WildMenu guifg=#000000 guibg=#ffff00 guisp=NONE gui=NONE ctermfg=16 ctermbg=226 cterm=NONE term=bold
hi lCursor guifg=#000000 guibg=#e5e5e5 guisp=NONE gui=NONE ctermfg=16 ctermbg=254 cterm=NONE term=NONE

if s:tgc || s:t_Co >= 256
  finish
endif

if s:t_Co >= 16
  hi Normal ctermfg=white ctermbg=black cterm=NONE
  hi ColorColumn ctermfg=white ctermbg=darkred cterm=NONE
  hi Comment ctermfg=blue ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=grey ctermbg=NONE cterm=NONE
  hi Constant ctermfg=darkmagenta ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=black ctermbg=green cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorIM ctermfg=NONE ctermbg=fg cterm=NONE
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLineNr ctermfg=yellow ctermbg=NONE cterm=bold
  hi DiffAdd ctermfg=white ctermbg=darkgreen cterm=NONE
  hi DiffChange ctermfg=white ctermbg=blue cterm=NONE
  hi DiffDelete ctermfg=white ctermbg=magenta cterm=NONE
  hi DiffText ctermfg=black ctermbg=grey cterm=NONE
  hi Directory ctermfg=cyan ctermbg=NONE cterm=NONE
  hi EndOfBuffer ctermfg=blue ctermbg=NONE cterm=NONE
  hi Error ctermfg=white ctermbg=red cterm=NONE
  hi ErrorMsg ctermfg=white ctermbg=darkred cterm=NONE
  hi FoldColumn ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Identifier ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=black ctermbg=black cterm=NONE
  hi IncSearch ctermfg=darkgreen ctermbg=black cterm=reverse
  hi LineNr ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi MatchParen ctermfg=NONE ctermbg=darkcyan cterm=NONE
  hi ModeMsg ctermfg=NONE ctermbg=NONE cterm=bold
  hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi NonText ctermfg=blue ctermbg=NONE cterm=NONE
  hi Pmenu ctermfg=fg ctermbg=darkgrey cterm=NONE
  hi PmenuMatch ctermfg=fg ctermbg=darkgrey cterm=bold
  hi PmenuMatchSel ctermfg=black ctermbg=yellow cterm=bold
  hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
  hi PmenuSel ctermfg=black ctermbg=yellow cterm=NONE
  hi PmenuThumb ctermfg=NONE ctermbg=grey cterm=NONE
  hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Question ctermfg=green ctermbg=NONE cterm=bold
  hi QuickFixLine ctermfg=black ctermbg=darkyellow cterm=NONE
  hi Search ctermfg=red ctermbg=black cterm=reverse
  hi SignColumn ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Special ctermfg=darkred ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=cyan ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=red ctermbg=NONE cterm=underline
  hi SpellCap ctermfg=blue ctermbg=NONE cterm=underline
  hi SpellLocal ctermfg=magenta ctermbg=NONE cterm=underline
  hi SpellRare ctermfg=cyan ctermbg=NONE cterm=underline
  hi Statement ctermfg=yellow ctermbg=NONE cterm=NONE
  hi StatusLine ctermfg=white ctermbg=darkblue cterm=bold
  hi StatusLineNC ctermfg=black ctermbg=grey cterm=NONE
  hi TabLine ctermfg=white ctermbg=darkgrey cterm=NONE
  hi TabLineFill ctermfg=NONE ctermbg=black cterm=reverse
  hi TabLineSel ctermfg=white ctermbg=black cterm=bold
  hi Title ctermfg=magenta ctermbg=NONE cterm=bold
  hi TitleBar ctermfg=white ctermbg=black cterm=NONE
  hi TitleBarNC ctermfg=darkgrey ctermbg=black cterm=NONE
  hi Todo ctermfg=yellow ctermbg=black cterm=reverse
  hi ToolbarButton ctermfg=black ctermbg=grey cterm=bold
  hi ToolbarLine ctermfg=NONE ctermbg=black cterm=NONE
  hi Type ctermfg=green ctermbg=NONE cterm=NONE
  hi Underlined ctermfg=blue ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=black ctermbg=darkblue cterm=NONE
  hi VertSplitNC ctermfg=black ctermbg=grey cterm=NONE
  hi Visual ctermfg=black ctermbg=grey cterm=NONE
  hi VisualNOS ctermfg=NONE ctermbg=black cterm=underline
  hi WarningMsg ctermfg=red ctermbg=NONE cterm=NONE
  hi WildMenu ctermfg=black ctermbg=yellow cterm=NONE
  hi lCursor ctermfg=black ctermbg=grey cterm=NONE
  finish
endif

if s:t_Co >= 8
  hi Normal ctermfg=grey ctermbg=black cterm=NONE
  hi ColorColumn ctermfg=white ctermbg=darkred cterm=NONE
  hi Comment ctermfg=darkblue ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=grey ctermbg=NONE cterm=NONE
  hi Constant ctermfg=darkmagenta ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=black ctermbg=green cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorIM ctermfg=NONE ctermbg=fg cterm=NONE
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLineNr ctermfg=darkyellow ctermbg=NONE cterm=bold,underline
  hi DiffAdd ctermfg=white ctermbg=darkgreen cterm=NONE
  hi DiffChange ctermfg=white ctermbg=darkblue cterm=NONE
  hi DiffDelete ctermfg=white ctermbg=darkmagenta cterm=NONE
  hi DiffText ctermfg=black ctermbg=grey cterm=NONE
  hi Directory ctermfg=darkcyan ctermbg=NONE cterm=bold
  hi EndOfBuffer ctermfg=darkblue ctermbg=NONE cterm=bold
  hi Error ctermfg=grey ctermbg=darkred cterm=NONE
  hi ErrorMsg ctermfg=grey ctermbg=darkred cterm=NONE
  hi FoldColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Identifier ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=black ctermbg=black cterm=NONE
  hi IncSearch ctermfg=darkgreen ctermbg=black cterm=reverse
  hi LineNr ctermfg=grey ctermbg=NONE cterm=bold
  hi MatchParen ctermfg=grey ctermbg=darkcyan cterm=NONE
  hi ModeMsg ctermfg=NONE ctermbg=NONE cterm=bold
  hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi NonText ctermfg=darkblue ctermbg=NONE cterm=bold
  hi Pmenu ctermfg=black ctermbg=darkcyan cterm=NONE
  hi PmenuMatch ctermfg=black ctermbg=darkcyan cterm=bold
  hi PmenuMatchSel ctermfg=black ctermbg=darkyellow cterm=bold
  hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
  hi PmenuSel ctermfg=black ctermbg=darkyellow cterm=NONE
  hi PmenuThumb ctermfg=NONE ctermbg=darkmagenta cterm=NONE
  hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=bold
  hi Question ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi QuickFixLine ctermfg=black ctermbg=darkyellow cterm=NONE
  hi Search ctermfg=darkred ctermbg=black cterm=bold,reverse
  hi SignColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Special ctermfg=darkred ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=darkred ctermbg=darkyellow cterm=reverse
  hi SpellCap ctermfg=darkblue ctermbg=darkyellow cterm=reverse
  hi SpellLocal ctermfg=darkmagenta ctermbg=darkyellow cterm=reverse
  hi SpellRare ctermfg=darkcyan ctermbg=NONE cterm=reverse
  hi Statement ctermfg=darkyellow ctermbg=NONE cterm=bold
  hi StatusLine ctermfg=grey ctermbg=darkblue cterm=bold
  hi StatusLineNC ctermfg=black ctermbg=grey cterm=NONE
  hi TabLine ctermfg=black ctermbg=grey cterm=NONE
  hi TabLineFill ctermfg=NONE ctermbg=black cterm=reverse
  hi TabLineSel ctermfg=white ctermbg=black cterm=bold
  hi Title ctermfg=darkmagenta ctermbg=NONE cterm=bold
  hi TitleBar ctermfg=white ctermbg=black cterm=NONE
  hi TitleBarNC ctermfg=darkgrey ctermbg=black cterm=NONE
  hi Todo ctermfg=darkyellow ctermbg=black cterm=reverse
  hi ToolbarButton ctermfg=grey ctermbg=black cterm=bold,reverse
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=grey ctermbg=darkblue cterm=NONE
  hi VertSplitNC ctermfg=black ctermbg=grey cterm=NONE
  hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
  hi VisualNOS ctermfg=NONE ctermbg=black cterm=underline
  hi WarningMsg ctermfg=darkred ctermbg=NONE cterm=NONE
  hi WildMenu ctermfg=black ctermbg=darkyellow cterm=NONE
  hi lCursor ctermfg=black ctermbg=grey cterm=NONE
  finish
endif

if s:t_Co >= 0
  hi CurSearch term=reverse
  hi CursorLineFold term=underline
  hi CursorLineSign term=underline
  hi Float term=NONE
  hi Function term=NONE
  hi Number term=NONE
  hi StatusLineTerm term=bold,reverse
  hi StatusLineTermNC term=bold,underline
  hi Terminal term=NONE
  finish
endif

" vim: et ts=8 sw=2 sts=2
