" Name:         ron
" Author:       original author Ron Aaron <ron@ronware.org>
" Maintainer:   original maintainer Ron Aaron <ron@ronware.org>
" URL:          https://www.github.com/vim/colorschemes
" License:      Same as Vim
" Last Change:  2026 May 30

" Generated by Colortemplate v3.0.0-rc1

set background=dark

hi clear
let g:colors_name = 'ron'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

let g:terminal_ansi_colors = ['#000000', '#cd0000', '#00cd00', '#cdcd00', '#0000ee', '#cd00cd', '#00cdcd', '#e5e5e5', '#7f7f7f', '#ff0000', '#00ff00', '#ffff00', '#5c5cff', '#ff00ff', '#00ffff', '#ffffff']

hi! link Boolean Constant
hi! link Character Constant
hi! link Conditional Statement
hi! link CurSearch Search
hi! link CursorLineFold CursorLine
hi! link CursorLineSign CursorLine
hi! link Debug Special
hi! link Define PreProc
hi! link Delimiter Special
hi! link Exception Statement
hi! link Float Constant
hi! link Function Identifier
hi! link Include PreProc
hi! link Keyword Statement
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link Macro PreProc
hi! link MessageWindow Pmenu
hi! link Number Constant
hi! link PopupNotification Todo
hi! link PreCondit PreProc
hi! link Repeat Statement
hi! link SpecialChar Special
hi! link SpecialComment Special
hi! link StatusLineTerm StatusLine
hi! link StatusLineTermNC StatusLineNC
hi! link StorageClass Type
hi! link String Constant
hi! link Structure Type
hi! link TabPanel EndOfBuffer
hi! link TabPanelFill EndOfBuffer
hi! link TabPanelSel TabLineSel
hi! link Tag Special
hi! link Typedef Type
hi! link lCursor Cursor

hi Normal guifg=#00ffff guibg=#000000 guisp=NONE gui=NONE ctermfg=51 ctermbg=16 cterm=NONE term=NONE
hi ColorColumn guifg=NONE guibg=#cd0000 guisp=NONE gui=NONE ctermfg=NONE ctermbg=160 cterm=NONE term=reverse
hi Comment guifg=#00ff00 guibg=NONE guisp=NONE gui=NONE ctermfg=46 ctermbg=NONE cterm=NONE term=bold
hi Conceal guifg=#666666 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
hi Constant guifg=#00ffff guibg=NONE guisp=NONE gui=bold ctermfg=51 ctermbg=NONE cterm=NONE term=NONE
hi Cursor guifg=#ffffff guibg=#60a060 guisp=NONE gui=NONE ctermfg=231 ctermbg=71 cterm=NONE term=reverse
hi CursorColumn guifg=NONE guibg=#666666 guisp=NONE gui=NONE ctermfg=NONE ctermbg=59 cterm=NONE term=NONE
hi CursorIM guifg=NONE guibg=fg guisp=NONE gui=NONE ctermfg=NONE ctermbg=fg cterm=NONE term=NONE
hi CursorLine guifg=NONE guibg=#666666 guisp=NONE gui=NONE ctermfg=NONE ctermbg=59 cterm=NONE term=underline
hi CursorLineNr guifg=#ffff00 guibg=NONE guisp=NONE gui=bold ctermfg=226 ctermbg=NONE cterm=NONE term=bold
hi DiffAdd guifg=#ffffff guibg=#5f875f guisp=NONE gui=NONE ctermfg=231 ctermbg=65 cterm=NONE term=reverse
hi DiffChange guifg=#ffffff guibg=#5f87af guisp=NONE gui=NONE ctermfg=231 ctermbg=67 cterm=NONE term=NONE
hi DiffDelete guifg=#ffffff guibg=#af5faf guisp=NONE gui=NONE ctermfg=231 ctermbg=133 cterm=NONE term=reverse
hi DiffText guifg=#000000 guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=16 ctermbg=251 cterm=NONE term=reverse
hi Directory guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=NONE
hi EndOfBuffer guifg=#ffff00 guibg=#303030 guisp=NONE gui=NONE ctermfg=226 ctermbg=236 cterm=NONE term=NONE
hi Error guifg=#ff0000 guibg=#ffffff guisp=NONE gui=reverse ctermfg=196 ctermbg=231 cterm=reverse term=bold,reverse
hi ErrorMsg guifg=#ff0000 guibg=#ffffff guisp=NONE gui=reverse ctermfg=196 ctermbg=231 cterm=reverse term=bold,reverse
hi FoldColumn guifg=#ffffff guibg=NONE guisp=NONE gui=NONE ctermfg=231 ctermbg=NONE cterm=NONE term=NONE
hi Folded guifg=NONE guibg=#4d4d4d guisp=NONE gui=NONE ctermfg=NONE ctermbg=239 cterm=NONE term=NONE
hi Identifier guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=NONE
hi Ignore guifg=#000000 guibg=#000000 guisp=NONE gui=NONE ctermfg=16 ctermbg=16 cterm=NONE term=NONE
hi IncSearch guifg=NONE guibg=#4682b4 guisp=NONE gui=NONE ctermfg=NONE ctermbg=67 cterm=NONE term=bold,reverse,underline
hi Label guifg=#eec900 guibg=NONE guisp=NONE gui=NONE ctermfg=220 ctermbg=NONE cterm=NONE term=NONE
hi LineNr guifg=#a9a9a9 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=NONE
hi MatchParen guifg=NONE guibg=#008b8b guisp=NONE gui=NONE ctermfg=NONE ctermbg=44 cterm=NONE term=bold,underline
hi ModeMsg guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=NONE term=bold
hi MoreMsg guifg=#2e8b57 guibg=NONE guisp=NONE gui=bold ctermfg=29 ctermbg=NONE cterm=NONE term=NONE
hi NonText guifg=#ffff00 guibg=#303030 guisp=NONE gui=NONE ctermfg=226 ctermbg=236 cterm=NONE term=NONE
hi Operator guifg=#ffa500 guibg=NONE guisp=NONE gui=NONE ctermfg=214 ctermbg=NONE cterm=NONE term=NONE
hi Pmenu guifg=#ffffff guibg=#444444 guisp=NONE gui=NONE ctermfg=231 ctermbg=238 cterm=NONE term=reverse
hi PmenuMatch guifg=#ff00ff guibg=#444444 guisp=NONE gui=NONE ctermfg=201 ctermbg=238 cterm=NONE term=NONE
hi PmenuMatchSel guifg=#ff00ff guibg=#00cdcd guisp=NONE gui=NONE ctermfg=201 ctermbg=44 cterm=NONE term=NONE
hi PmenuSbar guifg=NONE guibg=#000000 guisp=NONE gui=NONE ctermfg=NONE ctermbg=16 cterm=NONE term=reverse
hi PmenuSel guifg=#000000 guibg=#00cdcd guisp=NONE gui=NONE ctermfg=16 ctermbg=44 cterm=NONE term=bold
hi PmenuThumb guifg=NONE guibg=#e5e5e5 guisp=NONE gui=NONE ctermfg=NONE ctermbg=254 cterm=NONE term=NONE
hi PreProc guifg=#eea9b8 guibg=NONE guisp=NONE gui=NONE ctermfg=217 ctermbg=NONE cterm=NONE term=NONE
hi Question guifg=#00ff00 guibg=#000000 guisp=NONE gui=bold ctermfg=46 ctermbg=16 cterm=NONE term=standout
hi QuickFixLine guifg=#000000 guibg=#00cdcd guisp=NONE gui=NONE ctermfg=16 ctermbg=44 cterm=NONE term=NONE
hi Search guifg=#000000 guibg=#a9a9a9 guisp=NONE gui=bold ctermfg=16 ctermbg=145 cterm=NONE term=reverse
hi SignColumn guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=reverse
hi Special guifg=#ffff00 guibg=NONE guisp=NONE gui=NONE ctermfg=226 ctermbg=NONE cterm=NONE term=NONE
hi SpecialKey guifg=#00ffff guibg=NONE guisp=NONE gui=NONE ctermfg=51 ctermbg=NONE cterm=NONE term=bold
hi SpellBad guifg=#ff0000 guibg=NONE guisp=#ff0000 gui=undercurl ctermfg=196 ctermbg=NONE cterm=underline term=underline
hi SpellCap guifg=#ffffff guibg=NONE guisp=#ffffff gui=undercurl ctermfg=231 ctermbg=NONE cterm=underline term=underline
hi SpellLocal guifg=#ffff00 guibg=NONE guisp=#ffff00 gui=undercurl ctermfg=226 ctermbg=NONE cterm=underline term=underline
hi SpellRare guifg=#ff00ff guibg=NONE guisp=#ff00ff gui=undercurl ctermfg=201 ctermbg=NONE cterm=underline term=underline
hi Statement guifg=#add8e6 guibg=NONE guisp=NONE gui=NONE ctermfg=152 ctermbg=NONE cterm=NONE term=NONE
hi StatusLine guifg=#00ffff guibg=#0000ff guisp=NONE gui=bold ctermfg=51 ctermbg=21 cterm=NONE term=bold,reverse
hi StatusLineNC guifg=#add8e6 guibg=#00008b guisp=NONE gui=NONE ctermfg=152 ctermbg=20 cterm=NONE term=bold,underline
hi TabLine guifg=#000000 guibg=#008b8b guisp=NONE gui=NONE ctermfg=16 ctermbg=44 cterm=NONE term=bold,underline
hi TabLineFill guifg=#a9a9a9 guibg=#7f7f7f guisp=NONE gui=NONE ctermfg=145 ctermbg=102 cterm=NONE term=NONE
hi TabLineSel guifg=#00ffff guibg=#000000 guisp=NONE gui=bold ctermfg=51 ctermbg=16 cterm=NONE term=bold,reverse
hi Terminal guifg=#00ffff guibg=#000000 guisp=NONE gui=NONE ctermfg=51 ctermbg=16 cterm=NONE term=NONE
hi Title guifg=#a9a9a9 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=NONE
hi TitleBar guifg=#00ffff guibg=#3c3c3c guisp=NONE gui=NONE ctermfg=51 ctermbg=237 cterm=NONE term=NONE
hi TitleBarNC guifg=#7f7f7f guibg=#2c2c2c guisp=NONE gui=NONE ctermfg=102 ctermbg=236 cterm=NONE term=NONE
hi Todo guifg=#000000 guibg=#ffa500 guisp=NONE gui=NONE ctermfg=16 ctermbg=214 cterm=NONE term=bold,reverse
hi ToolbarButton guifg=#000000 guibg=#e5e5e5 guisp=NONE gui=bold ctermfg=16 ctermbg=254 cterm=NONE term=bold,reverse
hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
hi Type guifg=#2e8b57 guibg=NONE guisp=NONE gui=bold ctermfg=29 ctermbg=NONE cterm=NONE term=NONE
hi Underlined guifg=#80a0ff guibg=NONE guisp=NONE gui=underline ctermfg=111 ctermbg=NONE cterm=underline term=underline
hi VertSplit guifg=#00ffff guibg=#0000ff guisp=NONE gui=NONE ctermfg=51 ctermbg=21 cterm=NONE term=NONE
hi VertSplitNC guifg=#add8e6 guibg=#00008b guisp=NONE gui=NONE ctermfg=152 ctermbg=20 cterm=NONE term=NONE
hi Visual guifg=NONE guibg=NONE guisp=NONE gui=reverse ctermfg=NONE ctermbg=NONE cterm=reverse term=reverse
hi VisualNOS guifg=NONE guibg=#000000 guisp=NONE gui=bold,underline ctermfg=NONE ctermbg=16 cterm=underline term=NONE
hi WarningMsg guifg=#ffff00 guibg=NONE guisp=NONE gui=NONE ctermfg=226 ctermbg=NONE cterm=NONE term=standout
hi WildMenu guifg=#000000 guibg=#ffff00 guisp=NONE gui=NONE ctermfg=16 ctermbg=226 cterm=NONE term=bold

if s:tgc || s:t_Co >= 256
  finish
endif

if s:t_Co >= 16
  hi Normal ctermfg=cyan ctermbg=black cterm=NONE
  hi ColorColumn ctermfg=cyan ctermbg=darkred cterm=NONE
  hi Comment ctermfg=green ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi Constant ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=white ctermbg=green cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorIM ctermfg=NONE ctermbg=fg cterm=NONE
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLineNr ctermfg=yellow ctermbg=NONE cterm=underline
  hi DiffAdd ctermfg=white ctermbg=darkgreen cterm=NONE
  hi DiffChange ctermfg=white ctermbg=blue cterm=NONE
  hi DiffDelete ctermfg=white ctermbg=magenta cterm=NONE
  hi DiffText ctermfg=black ctermbg=grey cterm=NONE
  hi Directory ctermfg=cyan ctermbg=NONE cterm=NONE
  hi EndOfBuffer ctermfg=yellow ctermbg=darkgrey cterm=NONE
  hi Error ctermfg=red ctermbg=white cterm=reverse
  hi ErrorMsg ctermfg=red ctermbg=white cterm=reverse
  hi FoldColumn ctermfg=white ctermbg=NONE cterm=NONE
  hi Folded ctermfg=NONE ctermbg=darkgrey cterm=NONE
  hi Identifier ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=black ctermbg=black cterm=NONE
  hi IncSearch ctermfg=NONE ctermbg=blue cterm=NONE
  hi Label ctermfg=yellow ctermbg=NONE cterm=NONE
  hi LineNr ctermfg=grey ctermbg=NONE cterm=NONE
  hi MatchParen ctermfg=NONE ctermbg=darkcyan cterm=NONE
  hi ModeMsg ctermfg=NONE ctermbg=NONE cterm=NONE
  hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi NonText ctermfg=yellow ctermbg=darkgrey cterm=NONE
  hi Operator ctermfg=darkyellow ctermbg=NONE cterm=NONE
  hi Pmenu ctermfg=white ctermbg=darkgrey cterm=NONE
  hi PmenuMatch ctermfg=white ctermbg=darkgrey cterm=bold
  hi PmenuMatchSel ctermfg=black ctermbg=darkcyan cterm=bold
  hi PmenuSbar ctermfg=NONE ctermbg=black cterm=NONE
  hi PmenuSel ctermfg=black ctermbg=darkcyan cterm=NONE
  hi PmenuThumb ctermfg=NONE ctermbg=grey cterm=NONE
  hi PreProc ctermfg=darkmagenta ctermbg=NONE cterm=NONE
  hi Question ctermfg=green ctermbg=black cterm=NONE
  hi QuickFixLine ctermfg=black ctermbg=darkcyan cterm=NONE
  hi Search ctermfg=black ctermbg=grey cterm=NONE
  hi SignColumn ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Special ctermfg=yellow ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=cyan ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=red ctermbg=NONE cterm=underline
  hi SpellCap ctermfg=white ctermbg=NONE cterm=underline
  hi SpellLocal ctermfg=yellow ctermbg=NONE cterm=underline
  hi SpellRare ctermfg=magenta ctermbg=NONE cterm=underline
  hi Statement ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi StatusLine ctermfg=cyan ctermbg=darkblue cterm=NONE
  hi StatusLineNC ctermfg=darkcyan ctermbg=darkblue cterm=NONE
  hi TabLine ctermfg=black ctermbg=darkcyan cterm=NONE
  hi TabLineFill ctermfg=grey ctermbg=darkgrey cterm=NONE
  hi TabLineSel ctermfg=cyan ctermbg=black cterm=NONE
  hi Terminal ctermfg=cyan ctermbg=black cterm=NONE
  hi Title ctermfg=grey ctermbg=NONE cterm=NONE
  hi TitleBar ctermfg=cyan ctermbg=black cterm=NONE
  hi TitleBarNC ctermfg=darkgrey ctermbg=black cterm=NONE
  hi Todo ctermfg=black ctermbg=darkyellow cterm=NONE
  hi ToolbarButton ctermfg=black ctermbg=grey cterm=NONE
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi Underlined ctermfg=blue ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=cyan ctermbg=darkblue cterm=NONE
  hi VertSplitNC ctermfg=darkcyan ctermbg=darkblue cterm=NONE
  hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
  hi VisualNOS ctermfg=NONE ctermbg=black cterm=underline
  hi WarningMsg ctermfg=yellow ctermbg=NONE cterm=NONE
  hi WildMenu ctermfg=black ctermbg=yellow cterm=NONE
  finish
endif

if s:t_Co >= 8
  hi Normal ctermfg=darkcyan ctermbg=black cterm=NONE
  hi ColorColumn ctermfg=darkcyan ctermbg=darkred cterm=NONE
  hi Comment ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=grey ctermbg=grey cterm=NONE
  hi Constant ctermfg=darkcyan ctermbg=NONE cterm=bold
  hi Cursor ctermfg=white ctermbg=green cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorIM ctermfg=NONE ctermbg=fg cterm=NONE
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLineNr ctermfg=darkyellow ctermbg=NONE cterm=underline
  hi DiffAdd ctermfg=white ctermbg=darkgreen cterm=NONE
  hi DiffChange ctermfg=white ctermbg=darkblue cterm=NONE
  hi DiffDelete ctermfg=white ctermbg=darkmagenta cterm=NONE
  hi DiffText ctermfg=black ctermbg=grey cterm=NONE
  hi Directory ctermfg=darkcyan ctermbg=NONE cterm=bold
  hi EndOfBuffer ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi Error ctermfg=darkred ctermbg=grey cterm=bold,reverse
  hi ErrorMsg ctermfg=darkred ctermbg=grey cterm=reverse
  hi FoldColumn ctermfg=grey ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkcyan ctermbg=black cterm=reverse
  hi Identifier ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=black ctermbg=black cterm=NONE
  hi IncSearch ctermfg=darkyellow ctermbg=darkblue cterm=NONE
  hi Label ctermfg=darkyellow ctermbg=NONE cterm=bold
  hi LineNr ctermfg=grey ctermbg=NONE cterm=bold
  hi MatchParen ctermfg=NONE ctermbg=darkcyan cterm=bold
  hi ModeMsg ctermfg=NONE ctermbg=NONE cterm=NONE
  hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi NonText ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi Operator ctermfg=darkyellow ctermbg=NONE cterm=NONE
  hi Pmenu ctermfg=grey ctermbg=darkgrey cterm=NONE
  hi PmenuMatch ctermfg=grey ctermbg=darkgrey cterm=bold
  hi PmenuMatchSel ctermfg=black ctermbg=darkcyan cterm=bold
  hi PmenuSbar ctermfg=NONE ctermbg=black cterm=NONE
  hi PmenuSel ctermfg=black ctermbg=darkcyan cterm=NONE
  hi PmenuThumb ctermfg=NONE ctermbg=grey cterm=NONE
  hi PreProc ctermfg=darkmagenta ctermbg=NONE cterm=NONE
  hi Question ctermfg=darkgreen ctermbg=black cterm=bold
  hi QuickFixLine ctermfg=black ctermbg=darkcyan cterm=NONE
  hi Search ctermfg=black ctermbg=grey cterm=NONE
  hi SignColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Special ctermfg=darkyellow ctermbg=NONE cterm=bold
  hi SpecialKey ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=darkred ctermbg=darkyellow cterm=reverse
  hi SpellCap ctermfg=darkyellow ctermbg=NONE cterm=reverse
  hi SpellLocal ctermfg=darkgreen ctermbg=NONE cterm=reverse
  hi SpellRare ctermfg=darkmagenta ctermbg=darkyellow cterm=reverse
  hi Statement ctermfg=darkblue ctermbg=NONE cterm=bold
  hi StatusLine ctermfg=darkblue ctermbg=grey cterm=bold,reverse
  hi StatusLineNC ctermfg=darkblue ctermbg=grey cterm=reverse
  hi TabLine ctermfg=black ctermbg=darkcyan cterm=NONE
  hi TabLineFill ctermfg=darkblue ctermbg=darkblue cterm=NONE
  hi TabLineSel ctermfg=darkcyan ctermbg=black cterm=bold
  hi Terminal ctermfg=darkcyan ctermbg=black cterm=NONE
  hi Title ctermfg=grey ctermbg=NONE cterm=bold
  hi TitleBar ctermfg=cyan ctermbg=black cterm=NONE
  hi TitleBarNC ctermfg=darkgrey ctermbg=black cterm=NONE
  hi Todo ctermfg=black ctermbg=darkyellow cterm=bold
  hi ToolbarButton ctermfg=grey ctermbg=black cterm=bold,reverse
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=darkblue ctermbg=darkblue cterm=NONE
  hi VertSplitNC ctermfg=darkblue ctermbg=darkblue cterm=NONE
  hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
  hi VisualNOS ctermfg=NONE ctermbg=black cterm=underline
  hi WarningMsg ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi WildMenu ctermfg=black ctermbg=darkgreen cterm=NONE
  finish
endif

if s:t_Co >= 0
  hi CurSearch term=reverse
  hi CursorLineFold term=underline
  hi CursorLineSign term=underline
  hi Float term=NONE
  hi Function term=NONE
  hi Number term=NONE
  hi StatusLineTerm term=bold,reverse
  hi StatusLineTermNC term=bold,underline
  finish
endif

" vim: et ts=8 sw=2 sts=2
